diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/doxygen.cpp doxygen-1.4.4-patched/src/doxygen.cpp
--- doxygen-1.4.4/src/doxygen.cpp	Wed Jul 20 05:25:22 2005
+++ doxygen-1.4.4-patched/src/doxygen.cpp	Sat Aug  6 16:35:12 2005
@@ -8726,9 +8726,6 @@
   msg("Generating index page...\n"); 
   writeIndex(*outputList);
 
-  msg("Generating file index...\n");
-  writeFileIndex(*outputList);
-
   msg("Generating example documentation...\n");
   generateExampleDocs();
 
@@ -8742,26 +8739,44 @@
   msg("Generating file documentation...\n");
   generateFileDocs();
   
-  msg("Generating class documentation...\n");
-  generateClassDocs();
-  
   msg("Generating page documentation...\n");
   generatePageDocs();
   
   msg("Generating group documentation...\n");
   generateGroupDocs();
 
-  if (Config_getBool("SHOW_DIRECTORIES"))
+  msg("Generating group index...\n");
+  writeGroupIndex(*outputList);
+ 
+  msg("Generating class documentation...\n");
+  generateClassDocs();
+  
+  if (Config_getBool("HAVE_DOT") && Config_getBool("GRAPHICAL_HIERARCHY"))
   {
-    msg("Generating directory documentation...\n");
-    generateDirDocs(*outputList);
+    msg("Generating graphical class hierarchy...\n");
+    writeGraphicalClassHierarchy(*outputList);
   }
 
   msg("Generating namespace index...\n");
   generateNamespaceDocs();
   
-  msg("Generating group index...\n");
-  writeGroupIndex(*outputList);
+  msg("Generating namespace member index...\n");
+  writeNamespaceMemberIndex(*outputList);
+
+  if (Config_getBool("GENERATE_LEGEND"))
+  {
+    msg("Generating graph info page...\n");
+    writeGraphInfo(*outputList);
+  }
+
+  if (Config_getBool("SHOW_DIRECTORIES"))
+  {
+    msg("Generating directory documentation...\n");
+    generateDirDocs(*outputList);
+  }
+
+  msg("Generating file index...\n");
+  writeFileIndex(*outputList);
  
   if (Config_getBool("SHOW_DIRECTORIES"))
   {
@@ -8775,18 +8790,9 @@
   msg("Generating file member index...\n");
   writeFileMemberIndex(*outputList);
   
-  msg("Generating namespace member index...\n");
-  writeNamespaceMemberIndex(*outputList);
-
   msg("Generating page index...\n");
   writePageIndex(*outputList);
   
-  if (Config_getBool("GENERATE_LEGEND"))
-  {
-    msg("Generating graph info page...\n");
-    writeGraphInfo(*outputList);
-  }
-
   //writeDirDependencyGraph(Config_getString("HTML_OUTPUT"));
   
   if (Config_getBool("GENERATE_RTF"))
@@ -8798,12 +8804,6 @@
     }
   }
   
-  if (Config_getBool("HAVE_DOT") && Config_getBool("GRAPHICAL_HIERARCHY"))
-  {
-    msg("Generating graphical class hierarchy...\n");
-    writeGraphicalClassHierarchy(*outputList);
-  }
-
   if (Doxygen::formulaList.count()>0 && Config_getBool("GENERATE_HTML"))
   {
     msg("Generating bitmaps for formulas in HTML...\n");
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/htmlgen.cpp doxygen-1.4.4-patched/src/htmlgen.cpp
--- doxygen-1.4.4/src/htmlgen.cpp	Sun Jul 10 10:54:16 2005
+++ doxygen-1.4.4-patched/src/htmlgen.cpp	Sat Aug  6 16:35:12 2005
@@ -69,6 +69,9 @@
 "	padding: 2px;\n"
 "	line-height: 140%;\n"
 "}\n"
+"TABLE.qindex {"
+"	font-size: 100%;"
+"}"
 "DIV.nav {\n"
 "	width: 100%;\n"
 "	background-color: #eeeeff;\n"
@@ -1429,7 +1432,7 @@
                                 bool hl,bool compact,bool &first,
                                 const QCString &relPath)
 {
-  if (!first && compact) t << " | ";
+  if (!first && compact) t << ", ";
   first=FALSE;
   if (!compact) t << "<li>";
   if (hl && compact)
@@ -1458,29 +1461,56 @@
 {
   bool first=TRUE;
   if (compact) 
-  {
     t << "<div class=\"qindex\">"; 
-  }
-  else 
-  {
-    t << "<ul>";
-  }
-
   if (Config_getBool("SEARCHENGINE"))
-  {
     t << "  <form class=\"search\" action=\"" << relPath 
       << "search.php\" method=\"get\">\n";
-  }
+  if(!compact)
+    t << "<ul>";
 
+  int columns=1; //start at 1 for main page (and "modules") column
+  bool hasClasses=FALSE;
+  bool hasNamespaces=FALSE;
+  bool hasFiles=FALSE;
+  bool hasOther=FALSE;
+  
+  //Classes?
+  if(hierarchyClasses>0
+     || annotatedClasses>0
+     || documentedClassMembers[CMHL_All]>0)
+    hasClasses=columns++;
+    
+  //Namespaces?
+  if(documentedNamespaces>0
+     || documentedNamespaceMembers[NMHL_All])
+    hasNamespaces=columns++;
+    
+  //Files?
+  if(documentedHtmlFiles>0
+     || Config_getBool("SHOW_DIRECTORIES") && documentedDirs>0
+     || documentedFileMembers[FMHL_All]>0)
+    hasFiles=columns++;
+
+  //Other (inc. search)?
+  if(indexedPages>0
+     || Doxygen::exampleSDict->count()>0
+     || Config_getBool("SEARCHENGINE"))
+    hasOther=columns++;
+
+  if (compact) 
+    t << "<table border=0 class=\"qindex\"><tr><td width=\""
+      << 100.0/columns << "%\" align=\"center\">"; 
+
+  // Main and Modules
   if (Config_getBool("GENERATE_TREEVIEW"))
   {
     startQuickIndexItem(t,"main"+Doxygen::htmlFileExtension,
-                        hli==HLI_Main,compact,first,relPath);
+                        hli==HLI_Main,compact,first=TRUE,relPath);
   }
   else
   {
     startQuickIndexItem(t,"index"+Doxygen::htmlFileExtension,
-                        hli==HLI_Main,compact,first,relPath);
+                        hli==HLI_Main,compact,first=TRUE,relPath);
   }
   t << fixSpaces(theTranslator->trMainPage());
   endQuickIndexItem(t);
@@ -1484,84 +1514,135 @@
   }
   t << fixSpaces(theTranslator->trMainPage());
   endQuickIndexItem(t);
-
   if (documentedGroups>0)
   {
+    if(compact)
+      t << "<hr>";
     startQuickIndexItem(t,"modules"+Doxygen::htmlFileExtension,
-                        hli==HLI_Modules,compact,first,relPath);
+                        hli==HLI_Modules,compact,first=TRUE,relPath);
     t << fixSpaces(theTranslator->trModules());
     endQuickIndexItem(t);
   } 
-  if (documentedNamespaces>0)
-  {
-    startQuickIndexItem(t,"namespaces"+Doxygen::htmlFileExtension,
-                        hli==HLI_Namespaces,compact,first,relPath);
-    if (Config_getBool("OPTIMIZE_OUTPUT_JAVA"))
-    {
-      t << fixSpaces(theTranslator->trPackages());
-    }
+  if(compact)
+    t << "</td>\n";
+
+  // Classes
+  if(hasClasses) {
+    if(compact)
+      t << "<td width=\"0px\" bgcolor=\"000000\"></td>\n"
+        << "<td valign=\"top\" width=\"" << 100.0/columns <<"%\" align=\"left\">"
+        << "<b>" << fixSpaces(theTranslator->trCompounds()) << ": </b><center>";
     else
+      t << "<li>Classes:\n<ul>";
+    first=TRUE;
+    if (annotatedClasses>0)
     {
-      t << theTranslator->trNamespaceList();
-    }
+      startQuickIndexItem(t,"annotated"+Doxygen::htmlFileExtension,
+                          hli==HLI_Annotated,compact,first,relPath);
+      t << fixSpaces(theTranslator->trList(true,true));
     endQuickIndexItem(t);
+      if (Config_getBool("ALPHABETICAL_INDEX"))
+      {
+        startQuickIndexItem(t,"classes"+Doxygen::htmlFileExtension,
+                            hli==HLI_Classes,compact,first,relPath);
+        t << fixSpaces(theTranslator->trIndex(true,true));
+        endQuickIndexItem(t);
+      }
   }
   if (hierarchyClasses>0)
   {
     startQuickIndexItem(t,"hierarchy"+Doxygen::htmlFileExtension,
                            hli==HLI_Hierarchy,compact,first,relPath);
-    t << fixSpaces(theTranslator->trClassHierarchy());
+      t << fixSpaces(theTranslator->trHierarchy(true,true));
     endQuickIndexItem(t);
   } 
-  if (annotatedClasses>0)
-  {
-    if (Config_getBool("ALPHABETICAL_INDEX"))
+    if (documentedClassMembers[CMHL_All]>0)
     {
-      startQuickIndexItem(t,"classes"+Doxygen::htmlFileExtension,
-                          hli==HLI_Classes,compact,first,relPath);
-      t << fixSpaces(theTranslator->trAlphabeticalList());
+      startQuickIndexItem(t,"functions"+Doxygen::htmlFileExtension,
+                          hli==HLI_Functions,compact,first,relPath);
+      t << fixSpaces(theTranslator->trMember(true,false));
       endQuickIndexItem(t);
     }
-    startQuickIndexItem(t,"annotated"+Doxygen::htmlFileExtension,
-                        hli==HLI_Annotated,compact,first,relPath);
-    t << fixSpaces(theTranslator->trCompoundList());
+    if(compact)
+      t << "</center></td>\n";
+    else
+      t << "</ul>\n";
+  }
+
+  // Namespaces
+  if(hasNamespaces) {
+    if(compact) {
+      t << "<td width=\"0px\" bgcolor=\"000000\"></td>\n"
+        << "<td valign=\"top\" width=\"" << 100.0/columns <<"%\" align=\"left\">";
+      if (Config_getBool("OPTIMIZE_OUTPUT_JAVA"))
+        t << "<b>" << fixSpaces(theTranslator->trPackages()) << ": </b><center>";
+      else
+        t << "<b>" << fixSpaces(theTranslator->trNamespace(true,false)) << ": </b><center>";
+    } else
+      t << "<li>Namespaces:\n<ul>";
+    first=TRUE;
+    if (documentedNamespaces>0)
+    {
+      startQuickIndexItem(t,"namespaces"+Doxygen::htmlFileExtension,
+                          hli==HLI_Namespaces,compact,first,relPath);
+      t << fixSpaces(theTranslator->trList(true,true));
     endQuickIndexItem(t);
   } 
-  if (Config_getBool("SHOW_DIRECTORIES") && documentedDirs>0)
+    if (documentedNamespaceMembers[NMHL_All]>0)
   {
-    startQuickIndexItem(t,"dirs"+Doxygen::htmlFileExtension,
-                        hli==HLI_Directories,compact,first,relPath);
-    t << fixSpaces(theTranslator->trDirectories());
+      startQuickIndexItem(t,"namespacemembers"+Doxygen::htmlFileExtension,
+                          hli==HLI_NamespaceMembers,compact,first,relPath);
+      t << fixSpaces(theTranslator->trMember(true,false));
     endQuickIndexItem(t);
   } 
+    if(compact)
+      t << "</center></td>\n";
+    else
+      t << "</ul>\n";
+  }
+
+  // Files
+  if(hasFiles) {
+    if(compact)
+      t << "<td width=\"0px\" bgcolor=\"000000\"></td>\n"
+        << "<td valign=\"top\" width=\"" << 100.0/columns <<"%\" align=\"left\">"
+        << "<b>" << fixSpaces(theTranslator->trFile(true,false)) << ": </b><center>";
+    else
+      t << "<li>Files:\n<ul>";
+    first=TRUE;
   if (documentedHtmlFiles>0)
   {
     startQuickIndexItem(t,"files"+Doxygen::htmlFileExtension,
                         hli==HLI_Files,compact,first,relPath);
-    t << fixSpaces(theTranslator->trFileList());
-    endQuickIndexItem(t);
-  } 
-  if (documentedNamespaceMembers[NMHL_All]>0)
-  {
-    startQuickIndexItem(t,"namespacemembers"+Doxygen::htmlFileExtension,
-                        hli==HLI_NamespaceMembers,compact,first,relPath);
-    t << fixSpaces(theTranslator->trNamespaceMembers());
+      t << fixSpaces(theTranslator->trList(true,true));
     endQuickIndexItem(t);
   }
-  if (documentedClassMembers[CMHL_All]>0)
+    if (Config_getBool("SHOW_DIRECTORIES") && documentedDirs>0)
   {
-    startQuickIndexItem(t,"functions"+Doxygen::htmlFileExtension,
-                        hli==HLI_Functions,compact,first,relPath);
-    t << fixSpaces(theTranslator->trCompoundMembers());
+      startQuickIndexItem(t,"dirs"+Doxygen::htmlFileExtension,
+                          hli==HLI_Directories,compact,first,relPath);
+      t << fixSpaces(theTranslator->trDirectories());
     endQuickIndexItem(t);
   } 
   if (documentedFileMembers[FMHL_All]>0)
   {
     startQuickIndexItem(t,"globals"+Doxygen::htmlFileExtension,
                         hli==HLI_Globals,compact,first,relPath);
-    t << fixSpaces(theTranslator->trFileMembers());
+      t << fixSpaces(theTranslator->trMember(true,false));
     endQuickIndexItem(t);
   } 
+    if(compact)
+      t << "</center></td>\n";
+    else
+      t << "</ul>\n";
+  }
+  
+  // Other
+  if(hasOther) {
+    if(compact)
+      t << "<td width=\"0px\" bgcolor=\"000000\"></td>\n"
+        << "<td valign=\"top\" width=\"" << 100.0/columns <<"%\" align=\"center\">";
+    first=TRUE;
   if (indexedPages>0)
   {
     startQuickIndexItem(t,"pages"+Doxygen::htmlFileExtension,
@@ -1580,7 +1661,7 @@
   {
     if (compact)
     {
-      t << "  | ";
+        t << "<hr>";
     }
     else
     {
@@ -1593,19 +1674,19 @@
     t << "\">" << searchFor << "&nbsp;";
     if (hli!=HLI_Search)
     {
-      t << "<input class=\"search\" type=\"text\" name=\"query\" value=\"\" size=\"20\" accesskey=\"s\"/>"
-           "</span></form>";
+        t << "<input class=\"search\" type=\"text\" name=\"query\" value=\"\" size=\"10\" accesskey=\"s\"/>"
+          << "</span>";
     }
   } 
-  if (hli!=HLI_Search)
-  {
+    if(hli!=HLI_Search) {
     if (compact) 
-    {
-      t << "</div>\n";
-    }
+        t << "</td></tr></table>";
     else 
-    {
       t << "</ul>\n";
+      if (Config_getBool("SEARCHENGINE"))
+        t << "</form>\n";
+      if (compact) 
+        t << "</div>\n";
     }
   }
 }
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/search.php doxygen-1.4.4-patched/src/search.php
--- doxygen-1.4.4/src/search.php	Sun Jul  3 12:31:24 2005
+++ doxygen-1.4.4-patched/src/search.php	Sat Aug  6 16:35:12 2005
@@ -288,8 +288,8 @@
   {
     $query=$_GET["query"];
   }
-  echo "<input class=\"search\" type=\"text\" name=\"query\" value=\"$query\" size=\"20\" accesskey=\"s\"/>\n";
-  echo "</span>\n";
+  echo "<input class=\"search\" type=\"text\" name=\"query\" value=\"$query\" size=\"10\" accesskey=\"s\"/>\n";
+  echo "</span></td></tr></table>\n";
   echo "</form>\n";
   echo "</div>\n";
   echo "<div class=\"searchresults\">\n";
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/search_php.h doxygen-1.4.4-patched/src/search_php.h
--- doxygen-1.4.4/src/search_php.h	Sun Jul  3 12:31:24 2005
+++ doxygen-1.4.4-patched/src/search_php.h	Sat Aug  6 16:35:12 2005
@@ -288,8 +288,8 @@
 "  {\n"
 "    $query=$_GET[\"query\"];\n"
 "  }\n"
-"  echo \"<input class=\\\"search\\\" type=\\\"text\\\" name=\\\"query\\\" value=\\\"$query\\\" size=\\\"20\\\" accesskey=\\\"s\\\"/>\\n\";\n"
-"  echo \"</span>\\n\";\n"
+"  echo \"<input class=\\\"search\\\" type=\\\"text\\\" name=\\\"query\\\" value=\\\"$query\\\" size=\\\"10\\\" accesskey=\\\"s\\\"/>\\n\";\n"
+"  echo \"</span></td></tr></table>\\n\";\n"
 "  echo \"</form>\\n\";\n"
 "  echo \"</div>\\n\";\n"
 "  echo \"<div class=\\\"searchresults\\\">\\n\";\n"
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/translator.h doxygen-1.4.4-patched/src/translator.h
--- doxygen-1.4.4/src/translator.h	Tue Apr  5 12:52:37 2005
+++ doxygen-1.4.4-patched/src/translator.h	Sat Aug  6 16:35:12 2005
@@ -439,6 +439,14 @@
 
     virtual QCString trOverloadText() = 0;
     
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.5
+//////////////////////////////////////////////////////////////////////////
+
+    virtual QCString trList(bool first_capital, bool singular) = 0;
+    virtual QCString trIndex(bool first_capital, bool singular) = 0;
+    virtual QCString trHierarchy(bool first_capital, bool singular) = 0;
+
 };
 
 #endif
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/translator_adapter.h doxygen-1.4.4-patched/src/translator_adapter.h
--- doxygen-1.4.4/src/translator_adapter.h	Sun Jul  3 12:31:24 2005
+++ doxygen-1.4.4-patched/src/translator_adapter.h	Sat Aug  6 16:35:12 2005
@@ -41,7 +41,19 @@
 
 };
 
-class TranslatorAdapter_1_4_1 : public TranslatorAdapterBase
+class TranslatorAdapter_1_4_5 : public TranslatorAdapterBase {
+    virtual QCString updateNeededMessage()
+    { return createUpdateNeededMessage(idLanguage(),"release 1.4.5"); }
+    
+	virtual QCString trList(bool first_capital, bool singular)
+	{ return english.trList(first_capital,singular); }
+	virtual QCString trIndex(bool first_capital, bool singular)
+	{ return english.trIndex(first_capital,singular); }
+	virtual QCString trHierarchy(bool first_capital, bool singular)
+	{ return english.trHierarchy(first_capital,singular); }
+};
+
+class TranslatorAdapter_1_4_1 : public TranslatorAdapter_1_4_5
 {
   public:
     virtual QCString updateNeededMessage()
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/translator_br.h doxygen-1.4.4-patched/src/translator_br.h
--- doxygen-1.4.4/src/translator_br.h	Thu Mar 24 16:57:54 2005
+++ doxygen-1.4.4-patched/src/translator_br.h	Sat Aug  6 16:35:12 2005
@@ -36,7 +36,7 @@
 #ifndef TRANSLATOR_BR_H
 #define TRANSLATOR_BR_H
 
-class TranslatorBrazilian : public Translator
+class TranslatorBrazilian : public TranslatorAdapter_1_4_1
 {
   public:
 
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/translator_ca.h doxygen-1.4.4-patched/src/translator_ca.h
--- doxygen-1.4.4/src/translator_ca.h	Mon May  9 14:57:54 2005
+++ doxygen-1.4.4-patched/src/translator_ca.h	Sat Aug  6 16:35:12 2005
@@ -39,7 +39,7 @@
 // Translator class (by the local maintainer) when the localized
 // translator is made up-to-date again.
 
-class TranslatorCatalan : public Translator
+class TranslatorCatalan : public TranslatorAdapter_1_4_1
 {
   public:
 
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/translator_cz.h doxygen-1.4.4-patched/src/translator_cz.h
--- doxygen-1.4.4/src/translator_cz.h	Tue Mar 15 14:02:30 2005
+++ doxygen-1.4.4-patched/src/translator_cz.h	Sat Aug  6 16:35:12 2005
@@ -84,7 +84,7 @@
 // Windows version. The version which does not call the function is
 // probably slightly faster.
 
-class TranslatorCzech : public Translator
+class TranslatorCzech : public TranslatorAdapter_1_4_1
 {
   private:
     /*! The decode() inline assumes the source written in the 
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/translator_de.h doxygen-1.4.4-patched/src/translator_de.h
--- doxygen-1.4.4/src/translator_de.h	Mon May  9 14:56:58 2005
+++ doxygen-1.4.4-patched/src/translator_de.h	Sat Aug  6 16:35:12 2005
@@ -114,7 +114,7 @@
 #ifndef TRANSLATOR_DE_H
 #define TRANSLATOR_DE_H
 
-class TranslatorGerman : public Translator
+class TranslatorGerman : public TranslatorAdapter_1_4_1
 {
   public:
 
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/translator_en.h doxygen-1.4.4-patched/src/translator_en.h
--- doxygen-1.4.4/src/translator_en.h	Sun Jul  3 12:31:24 2005
+++ doxygen-1.4.4-patched/src/translator_en.h	Sat Aug  6 16:35:12 2005
@@ -226,7 +226,7 @@
 
     /*! This is put above each page as a link to all related pages. */
     virtual QCString trRelatedPages()
-    { return "Related Pages"; }
+    { return "Other Pages"; }
 
     /*! This is put above each page as a link to all examples. */
     virtual QCString trExamples()
@@ -1508,7 +1508,7 @@
      */
     virtual QCString trSearchForIndex()
     {
-      return "Search for";
+      return "Search";
     }
     /*! This string is used as the title for the page listing the search
      *  results.
@@ -1619,6 +1619,30 @@
               "provided for convenience. It differs from the above "
               "function only in what argument(s) it accepts.";
     }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.5
+//////////////////////////////////////////////////////////////////////////
+
+    virtual QCString trList(bool first_capital, bool singular)
+    {
+      QCString result(first_capital?"List":"list");
+      if (!singular) result+="s";
+      return result;
+    }
+    virtual QCString trIndex(bool first_capital, bool singular)
+    {
+      QCString result(first_capital?"Ind":"ind");
+      if (singular) result+="ex"; else result+="icies";
+      return result;
+    }
+    virtual QCString trHierarchy(bool first_capital, bool singular)
+    {
+      QCString result(first_capital?"Hierarch":"hierarch");
+      if (singular) result+="y"; else result+="ies";
+      return result;
+    }
+
 };
 
 #endif
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/translator_fr.h doxygen-1.4.4-patched/src/translator_fr.h
--- doxygen-1.4.4/src/translator_fr.h	Tue Jul 12 13:17:00 2005
+++ doxygen-1.4.4-patched/src/translator_fr.h	Sat Aug  6 16:35:12 2005
@@ -87,7 +87,7 @@
 // Translator class (by the local maintainer) when the localized
 // translator is made up-to-date again.
 
-class TranslatorFrench : public Translator
+class TranslatorFrench : public TranslatorAdapter_1_4_1
 {
   public:
 
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/translator_hr.h doxygen-1.4.4-patched/src/translator_hr.h
--- doxygen-1.4.4/src/translator_hr.h	Thu Mar 24 16:58:56 2005
+++ doxygen-1.4.4-patched/src/translator_hr.h	Sat Aug  6 16:35:12 2005
@@ -69,7 +69,7 @@
 #ifndef TRANSLATOR_HR_H
 #define TRANSLATOR_HR_H
 
-class TranslatorCroatian : public Translator
+class TranslatorCroatian : public TranslatorAdapter_1_4_1
 {
   private:
         /*! to avoid macro redefinition from translator_cz.h */
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/translator_hu.h doxygen-1.4.4-patched/src/translator_hu.h
--- doxygen-1.4.4/src/translator_hu.h	Sat Apr 30 06:00:56 2005
+++ doxygen-1.4.4-patched/src/translator_hu.h	Sat Aug  6 16:35:12 2005
@@ -29,7 +29,7 @@
 #ifndef TRANSLATOR_HU_H
 #define TRANSLATOR_HU_H
 
-class TranslatorHungarian : public Translator
+class TranslatorHungarian : public TranslatorAdapter_1_4_1
 {
   private:
     const char * zed(char c)
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/translator_id.h doxygen-1.4.4-patched/src/translator_id.h
--- doxygen-1.4.4/src/translator_id.h	Thu Jun 23 17:07:23 2005
+++ doxygen-1.4.4-patched/src/translator_id.h	Sat Aug  6 16:35:12 2005
@@ -23,7 +23,7 @@
 
   \author Hendy Irawan <ceefour@gauldong.net>
  */
-class TranslatorIndonesian : public Translator
+class TranslatorIndonesian : public TranslatorAdapter_1_4_1
 {
   public:
 
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/translator_it.h doxygen-1.4.4-patched/src/translator_it.h
--- doxygen-1.4.4/src/translator_it.h	Wed Mar 16 13:15:20 2005
+++ doxygen-1.4.4-patched/src/translator_it.h	Sat Aug  6 16:35:12 2005
@@ -74,7 +74,7 @@
 #ifndef TRANSLATOR_IT_H
 #define TRANSLATOR_IT_H
 
-class TranslatorItalian : public Translator
+class TranslatorItalian : public TranslatorAdapter_1_4_1
 {
   public:
 
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/translator_kr.h doxygen-1.4.4-patched/src/translator_kr.h
--- doxygen-1.4.4/src/translator_kr.h	Mon Apr  4 16:07:56 2005
+++ doxygen-1.4.4-patched/src/translator_kr.h	Sat Aug  6 16:35:12 2005
@@ -80,7 +80,7 @@
 //
  
 
-class TranslatorKorean : public Translator
+class TranslatorKorean : public TranslatorAdapter_1_4_1
 {
  private:
   	
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/translator_lt.h doxygen-1.4.4-patched/src/translator_lt.h
--- doxygen-1.4.4/src/translator_lt.h	Mon May  9 14:58:28 2005
+++ doxygen-1.4.4-patched/src/translator_lt.h	Sat Aug  6 16:35:12 2005
@@ -32,7 +32,7 @@
 #define TRANSLATOR_LT_H
 
 
-class TranslatorLithuanian : public Translator
+class TranslatorLithuanian : public TranslatorAdapter_1_4_1
 {
   public:
 
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/translator_nl.h doxygen-1.4.4-patched/src/translator_nl.h
--- doxygen-1.4.4/src/translator_nl.h	Sun Mar  6 14:53:23 2005
+++ doxygen-1.4.4-patched/src/translator_nl.h	Sat Aug  6 16:35:12 2005
@@ -1214,6 +1214,29 @@
              "bovenstaande functie wat betreft de parameterlijst.";
     }
     
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.5
+//////////////////////////////////////////////////////////////////////////
+
+    virtual QCString trList(bool first_capital, bool singular)
+    {
+      QCString result(first_capital?"Lijst":"lijst");
+      if (!singular) result+="s";
+      return result;
+    }
+    virtual QCString trIndex(bool first_capital, bool singular)
+    {
+      QCString result(first_capital?"Ind":"ind");
+      if (singular) result+="ex"; else result+="icies";
+      return result;
+    }
+    virtual QCString trHierarchy(bool first_capital, bool singular)
+    {
+      QCString result(first_capital?"Hi&euml;rarchie":"Hi&euml;rarchie");
+      if (!singular) result+="s";
+      return result;
+    }
+
 };
 
 #endif
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/translator_pl.h doxygen-1.4.4-patched/src/translator_pl.h
--- doxygen-1.4.4/src/translator_pl.h	Thu May 12 15:33:47 2005
+++ doxygen-1.4.4-patched/src/translator_pl.h	Sat Aug  6 16:35:12 2005
@@ -20,7 +20,7 @@
 #ifndef TRANSLATOR_PL_H
 #define TRANSLATOR_PL_H
 
-class TranslatorPolish : public Translator
+class TranslatorPolish : public TranslatorAdapter_1_4_1
 {
   private:
     /*! to avoid macro redefinition from translator_pl.h */
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/translator_ru.h doxygen-1.4.4-patched/src/translator_ru.h
--- doxygen-1.4.4/src/translator_ru.h	Tue Mar 15 14:01:04 2005
+++ doxygen-1.4.4-patched/src/translator_ru.h	Sat Aug  6 16:35:12 2005
@@ -49,7 +49,7 @@
 #ifndef TRANSLATOR_RU_H
 #define TRANSLATOR_RU_H
 
-class TranslatorRussian : public Translator
+class TranslatorRussian : public TranslatorAdapter_1_4_1
 {
   private:
     /*! The decode() inline assumes the source written in the 
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/translator_se.h doxygen-1.4.4-patched/src/translator_se.h
--- doxygen-1.4.4/src/translator_se.h	Tue Mar  8 17:14:22 2005
+++ doxygen-1.4.4-patched/src/translator_se.h	Sat Aug  6 16:35:12 2005
@@ -1431,6 +1431,29 @@
              "argument den tar emot.";
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.5
+//////////////////////////////////////////////////////////////////////////
+
+    virtual QCString trList(bool first_capital, bool singular)
+    {
+      QCString result(first_capital?"Lista":"lista");
+      if (!singular) result+="er";
+      return result;
+    }
+    virtual QCString trIndex(bool first_capital, bool singular)
+    {
+      QCString result(first_capital?"Ind":"ind");
+      if (singular) result+="ex"; else result+="icies";
+      return result;
+    }
+    virtual QCString trHierarchy(bool first_capital, bool singular)
+    {
+      QCString result(first_capital?"hierarki":"hierarki");
+      if (!singular) result+="er";
+      return result;
+    }
+
 	
 };
 
diff -urbB --minimal --exclude=Makefile* --exclude=*.pro doxygen-1.4.4/src/translator_za.h doxygen-1.4.4-patched/src/translator_za.h
--- doxygen-1.4.4/src/translator_za.h	Tue Apr 26 14:29:49 2005
+++ doxygen-1.4.4-patched/src/translator_za.h	Sat Aug  6 16:35:12 2005
@@ -26,7 +26,7 @@
 #ifndef TRANSLATOR_ZA_H
 #define TRANSLATOR_ZA_H
 
-class TranslatorAfrikaans : public Translator
+class TranslatorAfrikaans : public TranslatorAdapter_1_4_1
 {
   public:
 
